@@ -66,15 +66,16 @@ def parse(*parts):
 
 @contextmanager
 def elasticsearch(host):
+    es = Elasticsearch([host])
     try:
-        es = Elasticsearch([host])
         yield es
     finally:
         es.indices.delete(index="ocdsindex_en", ignore=[404])
         es.indices.delete(index="ocdsindex_es", ignore=[404])
+        es.close()
 
 
 def search(es, index):
-    es.indices.refresh(index)
+    es.indices.refresh(index=index)
 
     return es.search(index=index, size=10000)["hits"]
