@@ -4,7 +4,7 @@ from collections import defaultdict
 
 from click.testing import CliRunner
 
-from ocdsindex.cli.__main__ import main
+from ocdsindex.__main__ import main
 from tests import elasticsearch, search
 
 
@@ -14,13 +14,13 @@ def test_copy(tmpdir):
     runner = CliRunner()
 
     with elasticsearch(host) as es:
-        result = runner.invoke(main, ["index", host, os.path.join("tests", "fixtures", "data.json")])
+        result = runner.invoke(main, ["index", host, os.path.join("tests", "fixtures", "success", "data.json")])
 
         assert result.exit_code == 0, traceback.print_exception(*result.exc_info)
         assert result.output == ""
 
-        es.indices.refresh("ocdsindex_en")
-        es.indices.refresh("ocdsindex_es")
+        es.indices.refresh(index="ocdsindex_en")
+        es.indices.refresh(index="ocdsindex_es")
 
         source = "https://standard.open-contracting.org/dev/"
         destination = "https://standard.open-contracting.org/copy/"
