@@ -5,7 +5,7 @@ import traceback
 
 from click.testing import CliRunner
 
-from ocdsindex.cli.__main__ import main
+from ocdsindex.__main__ import main
 from tests import elasticsearch, search
 
 
@@ -15,7 +15,7 @@ def test_expire(tmpdir):
     runner = CliRunner()
 
     filename = tmpdir.join("data.json")
-    with open(os.path.join("tests", "fixtures", "data.json")) as f:
+    with open(os.path.join("tests", "fixtures", "success", "data.json")) as f:
         data = json.load(f)
 
     exclude_file = tmpdir.join("exclude.txt")
