@@ -4,7 +4,7 @@ import traceback
 
 from click.testing import CliRunner
 
-from ocdsindex.cli.__main__ import main
+from ocdsindex.__main__ import main
 from tests import elasticsearch, search
 
 
@@ -14,7 +14,7 @@ def test_index(tmpdir):
     runner = CliRunner()
 
     filename = tmpdir.join("data.json")
-    with open(os.path.join("tests", "fixtures", "data.json")) as f:
+    with open(os.path.join("tests", "fixtures", "success", "data.json")) as f:
         data = json.load(f)
 
     with elasticsearch(host) as es:
@@ -24,10 +24,10 @@ def test_index(tmpdir):
         assert result.exit_code == 0, traceback.print_exception(*result.exc_info)
         assert result.output == ""
 
-        assert es.indices.exists("ocdsindex_en")
-        assert es.indices.exists("ocdsindex_es")
+        assert es.indices.exists(index="ocdsindex_en")
+        assert es.indices.exists(index="ocdsindex_es")
 
-        assert es.indices.get("ocdsindex_en")["ocdsindex_en"]["mappings"] == {
+        assert es.indices.get(index="ocdsindex_en")["ocdsindex_en"]["mappings"] == {
             "properties": {
                 "title": {"analyzer": "english", "type": "text"},
                 "text": {"analyzer": "english", "type": "text"},
@@ -36,7 +36,7 @@ def test_index(tmpdir):
                 "url": {"fields": {"keyword": {"ignore_above": 256, "type": "keyword"}}, "type": "text"},
             }
         }
-        assert es.indices.get("ocdsindex_es")["ocdsindex_es"]["mappings"] == {
+        assert es.indices.get(index="ocdsindex_es")["ocdsindex_es"]["mappings"] == {
             "properties": {
                 "title": {"analyzer": "spanish", "type": "text"},
                 "text": {"analyzer": "spanish", "type": "text"},
@@ -82,7 +82,7 @@ def test_index(tmpdir):
         # Re-index
 
         data["documents"]["en"] = [data["documents"]["en"][-1]]
-        data["documents"].pop("es")
+        del data["documents"]["es"]
 
         filename.write(json.dumps(data))
         result = runner.invoke(main, ["index", host, str(filename)])
